==> ocrad-0.10.tar.bz2: ocrad-0.10/bitmap.h <==
/*  GNU Ocrad - Optical Character Recognition program
    Copyright (C) 2003, 2004 Antonio Diaz Diaz.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

// Only "P1" (pbm) and "P4" (pbm RAWBITS) file formats are recognized.

class Track;

class Bitmap
  {
  int _height;
  int _width;
  std::vector< std::vector< bool > > data;
  std::vector< Rectangle > _rectangle_vector;

  int  find_columns( int rindex ) throw();
  bool find_rows_and_columns() throw();
  void mirror_diagonal() throw();
  static void floodfill4( const Bitmap & source, Bitmap & dest,
                          int row, int col ) throw();
public:
  struct Error
    {
    const char * s;
    Error( const char * p ) { s = p; }
    };

  enum Type { vertical_histogram, horizontal_histogram, connected_ground };

	// Creates a Bitmap from a pbm file
  Bitmap( FILE * f, bool invert ) throw( Error );
	// Creates a Bitmap from another Bitmap
  Bitmap( const Bitmap & source, const Rectangle & r ) throw();
	// Creates a reduced bitmap
  Bitmap( const Bitmap & source, int scale, int th ) throw();
	// Creates a "special" type of Bitmap
  Bitmap( const Bitmap & source, Type t ) throw( Error );
	// Creates a Bitmap from a matrix of int
  Bitmap( const std::vector< std::vector< int > > & matrix ) throw();

  int height() const throw() { return _height; }
  int width()  const throw() { return _width;  }
  bool get_bit( int row, int col ) const throw() { return data[row][col]; }
  void set_bit( int row, int col, bool bit ) throw() { data[row][col] = bit; }
  void draw_rectangle( const Rectangle & r ) throw();
  void draw_track( const Track & t ) throw();

  const std::vector< Rectangle > & rectangle_vector() const throw()
    { return _rectangle_vector; }
  int rectangles() const throw() { return _rectangle_vector.size(); }

  int  analyse_layout( int layout_level ) throw();
  bool only_this_rectangle( int i ) throw();
  void save( FILE *, char filetype = '4' ) const throw();
  void transform( const Transformation & t ) throw();
  };

==> ocrad-0.11.tar.bz2: ocrad-0.11/bitmap.h <==
/*  GNU Ocrad - Optical Character Recognition program
    Copyright (C) 2003, 2004, 2005 Antonio Diaz Diaz.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

// Only "P1" (pbm) and "P4" (pbm RAWBITS) file formats are recognized.

class Track;

class Bitmap
  {
  int _height;
  int _width;
  std::vector< std::vector< bool > > data;
  std::vector< Rectangle > _rectangle_vector;

  int  find_columns( int rindex ) throw();
  bool find_rows_and_columns() throw();
  static void floodfill4( const Bitmap & source, Bitmap & dest,
                          int row, int col ) throw();
public:
  struct Error
    {
    const char * s;
    Error( const char * p ) { s = p; }
    };

  enum Type { vertical_histogram, horizontal_histogram, connected_ground };

	// Creates a Bitmap from a pbm file
  Bitmap( FILE * f, bool invert ) throw( Error );
	// Creates a Bitmap from another Bitmap
  Bitmap( const Bitmap & source, const Rectangle & r ) throw();
	// Creates a reduced bitmap
  Bitmap( const Bitmap & source, int scale, int th ) throw();
	// Creates a "special" type of Bitmap
  Bitmap( const Bitmap & source, Type t ) throw( Error );
	// Creates a Bitmap from a matrix of int
  Bitmap( const std::vector< std::vector< int > > & matrix ) throw();

  int height() const throw() { return _height; }
  int width()  const throw() { return _width;  }
  const std::vector< Rectangle > & rectangle_vector() const throw()
    { return _rectangle_vector; }
  int rectangles() const throw() { return _rectangle_vector.size(); }

  bool get_bit( int row, int col ) const throw() { return data[row][col]; }
  void set_bit( int row, int col, bool bit ) throw() { data[row][col] = bit; }

  int  analyse_layout( const int layout_level ) throw();
  bool only_this_rectangle( const int i ) throw();
  void save( FILE *, char filetype = '4' ) const throw();

  void draw_rectangle( const Rectangle & r ) throw();
  void draw_track( const Track & t ) throw();
  bool scale( const int n, const int th ) throw();
  void transform( const Transformation & t ) throw();
  };
